@@ -95,9 +95,6 @@ class MPScanRelaxSet2D(DictSet):
         self.bandgap = bandgap
         self.kwargs = kwargs
 
-        if self.potcar_functional not in ["PBE_52", "PBE_54"]:
-            raise ValueError("SCAN calculations require PBE_52 or PBE_54!")
-
         # self.kwargs.get("user_incar_settings", {
         updates = {}
         # select the KSPACING and smearing parameters based on the bandgap
